; NOTE: this .NSI script is designed for NSIS v1.8+
;
; This is a setup script that installs both the SatForms runtime engine and the compiled application
; together as a single listed application using two CAB files (RDK runtime CAB plus your app CAB)
; Both the SatForms runtime and your app will be listed in the Remove Programs tool and both
; must be accepted during the install process
; Note that all files are also installed to the PC hard drive in the INSTDIR folder

Name "SampleCo Work Order"
Icon "WorkOrderInstall.ico"     ;note this is not the same icon as the Work.ico used by SatForms
OutFile "WorkOrderInstall.exe"

; Some default compiler settings (uncomment and change at will):
; SetCompress auto ; (can be off or force)
; SetDatablockOptimize on ; (can be off)
; CRCCheck on ; (can be off)
; AutoCloseWindow false ; (can be true for the window go away automatically at end)
; ShowInstDetails hide ; (can be show to have them shown, or nevershow to disable)
; SetDateSave off ; (can be on to have files restored to their orginal date)

; BrandingText " "    ;hides the "NullSoft Install System" text if desired

LicenseText "You must agree to this license before installing."
LicenseData "eula.txt"
; Note: if you do not want to display a license dialog first just comment out the above two lines

; Note: this is the path on the PC (not the PDA) where the files will be installed
; The PDA install location is defined in the CAB file itself
InstallDir "$PROGRAMFILES\Work Order"
InstallDirRegKey HKEY_LOCAL_MACHINE "SOFTWARE\SampleCo\Work Order" ""

ComponentText "NOTE: The first component installed is the Satellite Forms Runtime, and the second component is the Work Order application. You must install both components." "" "Application:"

Section "SampleCo Work Order" ; (default, required section)
SetOutPath "$INSTDIR"

File eula.txt
File readme.txt

File WorkOrder.ini
File WorkOrder.Arm.CAB

File SatFormsRuntimeRDK.ini
File SatFormsRuntimeRDK.Arm.CAB

; one-time initialization needed for InstallCAB subroutine
ReadRegStr $0 HKEY_LOCAL_MACHINE "software\Microsoft\Windows\CurrentVersion\App Paths\CEAppMgr.exe" ""
IfErrors Error
Goto End
Error:
MessageBox MB_OK|MB_ICONEXCLAMATION \
"Unable to find Application Manager for PocketPC applications. \
Please install ActiveSync and reinstall this application."
End:

StrCpy $1 "$INSTDIR\WorkOrder.ini"
StrCpy $2 "$INSTDIR\SatFormsRuntimeRDK.ini"
Call InstallCAB

SectionEnd ; end of default section

Section "-post" ; (post install section, happens last after any optional sections) ; add any commands that need to happen after any optional sections here
WriteRegStr HKEY_LOCAL_MACHINE "SOFTWARE\SampleCo\Work Order" "" "$INSTDIR"
WriteRegStr HKEY_LOCAL_MACHINE "Software\Microsoft\Windows\CurrentVersion\Uninstall\SampleCo Work Order" "DisplayName" "SampleCo Work Order (remove only)"
WriteRegStr HKEY_LOCAL_MACHINE "Software\Microsoft\Windows\CurrentVersion\Uninstall\SampleCo Work Order" "UninstallString" '"$INSTDIR\uninst.exe"'

; write out uninstaller
WriteUninstaller "$INSTDIR\uninst.exe"

; NOTE you can comment out these messagebox lines down to the Quit keyword if you do not want to show a readme
MessageBox MB_YESNO|MB_ICONQUESTION \
  "Setup has completed. View readme file now?" \
  IDNO NoReadme

  ExecShell open '$INSTDIR\readme.txt'

  NoReadme:

  Quit
SectionEnd ; end of -post section

ShowInstDetails nevershow ;never show installation details

; begin uninstall settings/section
UninstallText "This will uninstall SampleCo Work Order from your system"

Section Uninstall
; add delete commands to delete whatever files/registry keys/etc you installed here.
Delete "$INSTDIR\uninst.exe"
Delete "$INSTDIR\eula.txt"
Delete "$INSTDIR\readme.txt"
Delete "$INSTDIR\SatFormsRuntimeRDK.ini"
Delete "$INSTDIR\SatFormsRuntimeRDK.Arm.CAB"
Delete "$INSTDIR\WorkOrder.ini"
Delete "$INSTDIR\WorkOrder.Arm.CAB"
DeleteRegKey HKEY_LOCAL_MACHINE "SOFTWARE\SampleCo\Work Order"
DeleteRegKey HKEY_LOCAL_MACHINE "SOFTWARE\Microsoft\Windows\CurrentVersion\Uninstall\SampleCo Work Order"
RMDir "$INSTDIR"
SectionEnd ; end of uninstall section


; Installs a PocketPC cab-application
; The var $0 contains the path to the CeAppMgr tool
; It expects $1 and $2 to contain the absolute location of the ini files
; to be installed.
Function InstallCAB

  ExecWait '"$0" "$1" "$2"'

FunctionEnd

; eof
